==> OpenOLAP_V1.0.zip: OpenOLAP/src/viewer/src/openolap/viewer/dao/PostgresUserDAO.java <==
/*  OpenOlap viewer
 *  pbP[WFopenolap.viewer.dao
 *  t@CFPostgresUserDAO.java
 *  F[U[̉iǗNXłB
 *
 *  쐬: 2004/01/30
 */
package openolap.viewer.dao;

import java.sql.Connection;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.sql.Statement;

import openolap.viewer.User;
import openolap.viewer.common.CommonUtils;

/**
 *  NXFPostgresUserDAO
 *  F[U[̉iǗNXłB
 */
public class PostgresUserDAO implements UserDAO {

	// ********** CX^Xϐ **********

	/** ConnectionIuWFNg */
	Connection conn = null;

	// ********** RXgN^ **********

	/**
	 *  [U[̉iǗIuWFNg𐶐܂B
	 */
	public PostgresUserDAO (Connection conn) {
		this.conn = conn;
	}

	/**
	 * ^ꂽ[U[ApX[hƂɃ[U[IuWFNg߂B<br>
	 * o^ĂȂꍇ̓OCsƂ݂ȂAnull߂B
	 * @param userName [U[
	 * @param password pX[h
	 * @return [U[IuWFNg
	 * @exception SQLException ɗO
	 */
	public User getUser(String userName, String password) throws SQLException {

		User user = null;

		String SQL = "";
		SQL += "select ";
		SQL += "    id,";				// id
		SQL += "    name,";				// [U
		SQL += "    adminflg, ";		// Ǘ҃tO
		SQL += "    export_file_type ";	// GNX|[g^Cv
		SQL += "from ";
		SQL += "    oo_v_user ";
		SQL += "where ";
		SQL += "    name='" + userName + "' and ";
		SQL += "    password='" + password + "'";
//System.out.println("select report SQL:" + SQL);

		Statement stmt = null;
		ResultSet rs = null;

		try {
			stmt = conn.createStatement();
			rs = stmt.executeQuery(SQL);

			while ( rs.next() ) {
				String id = rs.getString("id");
				String name = rs.getString("name");
				String adminflg = rs.getString("adminflg");

				user = new User(rs.getString("id"),
								 rs.getString("name"),
								 CommonUtils.FLGTobool(rs.getString("adminflg")),
								 rs.getString("export_file_type"));
			}
		

		} catch (SQLException e) {
			throw e;
		} catch (Exception e) { 
			e.printStackTrace();
		} finally {
			try {
				if (rs != null){
					rs.close();
				}
			} catch (SQLException e) {
				throw e;
			} finally {
				try {
					if (stmt != null){
						stmt.close();
					}
				} catch (SQLException e) {
					throw e;
				}
			}
		}
		
		return user;
	}
}

==> OpenOLAP_V1.2.0.zip: OpenOLAP/src/viewer/src/openolap/viewer/dao/PostgresUserDAO.java <==
/*  OpenOlap viewer
 *  pbP[WFopenolap.viewer.dao
 *  t@CFPostgresUserDAO.java
 *  F[U[̉iǗNXłB
 *
 *  쐬: 2004/01/30
 */
package openolap.viewer.dao;

import java.sql.Connection;
import java.sql.ResultSet;
import java.sql.SQLException;
import java.sql.Statement;

import openolap.viewer.User;

/**
 *  NXFPostgresUserDAO<br>
 *  F[U[̉iǗNXłB
 */
public class PostgresUserDAO implements UserDAO {

	// ********** CX^Xϐ **********

	/** ConnectionIuWFNg */
	Connection conn = null;

	// ********** RXgN^ **********

	/**
	 *  [U[̉iǗIuWFNg𐶐܂B
	 */
	public PostgresUserDAO (Connection conn) {
		this.conn = conn;
	}


	// ********** \bh **********
	
	/**
	 * ^ꂽ[U[ApX[hƂɃ[U[IuWFNg߂B<br>
	 * o^ĂȂꍇ̓OCsƂ݂ȂAnull߂B
	 * @param userName [U[
	 * @param password pX[h
	 * @return [U[IuWFNg
	 * @exception SQLException ɗO
	 */
	public User getUser(String userName, String password) throws SQLException {

		User user = null;

		String SQL = "";
		SQL += "select ";
		SQL += "    user_id,";				// id
		SQL += "    name,";				// [U
		SQL += "    adminflg, ";		// Ǘ҃tO
		SQL += "    export_file_type ";	// GNX|[g^Cv
		SQL += "from ";
		SQL += "    oo_v_user ";
		SQL += "where ";
		SQL += "    name='" + userName + "' and ";
		SQL += "    password='" + password + "'";
//System.out.println("select report SQL:" + SQL);

		Statement stmt = null;
		ResultSet rs = null;

		try {
			stmt = conn.createStatement();
			rs = stmt.executeQuery(SQL);

			while ( rs.next() ) {
				user = new User(rs.getString("user_id"),
								 rs.getString("name"),
								 rs.getString("adminflg"),
								 rs.getString("export_file_type"));
			}
		

		} catch (SQLException e) {
			throw e;
		} catch (Exception e) { 
			e.printStackTrace();
		} finally {
			try {
				if (rs != null){
					rs.close();
				}
			} catch (SQLException e) {
				throw e;
			} finally {
				try {
					if (stmt != null){
						stmt.close();
					}
				} catch (SQLException e) {
					throw e;
				}
			}
		}
		
		return user;
	}

}
